@@ -10,6 +10,7 @@ from __future__ import (
 
 import pytest
 
+from pptx.dml.fill import FillFormat
 from pptx.enum.shapes import PP_PLACEHOLDER
 from pptx.parts.presentation import PresentationPart
 from pptx.parts.slide import SlideLayoutPart, SlideMasterPart, SlidePart
@@ -20,8 +21,8 @@ from pptx.shapes.shapetree import (
     NotesSlidePlaceholders, NotesSlideShapes, SlidePlaceholders, SlideShapes
 )
 from pptx.slide import (
-    _BaseMaster, _BaseSlide, NotesMaster, NotesSlide, Slide, SlideLayout,
-    SlideLayouts, SlideMaster, SlideMasters, Slides
+    _Background, _BaseMaster, _BaseSlide, NotesMaster, NotesSlide, Slide,
+    SlideLayout, SlideLayouts, SlideMaster, SlideMasters, Slides
 )
 from pptx.text.text import TextFrame
 
@@ -42,8 +43,24 @@ class Describe_BaseSlide(object):
         base_slide.name = new_value
         assert base_slide._element.xml == expected_xml
 
+    def it_provides_access_to_its_background(self, background_fixture):
+        slide, _Background_, cSld, background_ = background_fixture
+
+        background = slide.background
+
+        _Background_.assert_called_once_with(cSld)
+        assert background is background_
+
     # fixtures -------------------------------------------------------
 
+    @pytest.fixture
+    def background_fixture(self, _Background_, background_):
+        sld = element('p:sld/p:cSld')
+        slide = _BaseSlide(sld, None)
+        cSld = sld.xpath('//p:cSld')[0]
+        _Background_.return_value = background_
+        return slide, _Background_, cSld, background_
+
     @pytest.fixture(params=[
         ('p:sld/p:cSld',              ''),
         ('p:sld/p:cSld{name=Foobar}', 'Foobar'),
@@ -67,6 +84,16 @@ class Describe_BaseSlide(object):
         expected_xml = xml(expected_cxml)
         return base_slide, new_value, expected_xml
 
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def _Background_(self, request):
+        return class_mock(request, 'pptx.slide._Background')
+
+    @pytest.fixture
+    def background_(self, request):
+        return instance_mock(request, _Background)
+
 
 class Describe_BaseMaster(object):
 
@@ -292,6 +319,19 @@ class DescribeSlide(object):
         slide = subclass_fixture
         assert isinstance(slide, _BaseSlide)
 
+    def it_provides_access_to_its_background(self, background_fixture):
+        slide, _BaseSlide_background_, background_ = background_fixture
+
+        background = slide.background
+
+        _BaseSlide_background_.assert_called_once_with()
+        assert background is background_
+
+    def it_knows_whether_it_follows_the_mstr_bkgd(self, follow_get_fixture):
+        slide, expected_value = follow_get_fixture
+        follows = slide.follow_master_background
+        assert follows is expected_value
+
     def it_knows_whether_it_has_a_notes_slide(self, has_notes_slide_fixture):
         slide, expected_value = has_notes_slide_fixture
         assert slide.has_notes_slide is expected_value
@@ -324,6 +364,21 @@ class DescribeSlide(object):
 
     # fixtures -------------------------------------------------------
 
+    @pytest.fixture
+    def background_fixture(self, _BaseSlide_background_, background_):
+        slide = Slide(None, None)
+        _BaseSlide_background_.return_value = background_
+        return slide, _BaseSlide_background_, background_
+
+    @pytest.fixture(params=[
+        ('p:sld/p:cSld',      True),
+        ('p:sld/p:cSld/p:bg', False),
+    ])
+    def follow_get_fixture(self, request):
+        pSld_cxml, expected_value = request.param
+        slide = Slide(element(pSld_cxml), None)
+        return slide, expected_value
+
     @pytest.fixture
     def has_notes_slide_fixture(self, part_prop_, slide_part_):
         slide = Slide(None, None)
@@ -370,6 +425,14 @@ class DescribeSlide(object):
 
     # fixture components ---------------------------------------------
 
+    @pytest.fixture
+    def _BaseSlide_background_(self, request):
+        return property_mock(request, _BaseSlide, 'background')
+
+    @pytest.fixture
+    def background_(self, request):
+        return instance_mock(request, _Background)
+
     @pytest.fixture
     def notes_slide_(self, request):
         return instance_mock(request, NotesSlide)
@@ -886,3 +949,48 @@ class DescribeSlideMasters(object):
     @pytest.fixture
     def slide_master_(self, request):
         return instance_mock(request, SlideMaster)
+
+
+class Describe_Background(object):
+
+    def it_provides_access_to_its_fill(self, fill_fixture):
+        background, cSld, expected_xml = fill_fixture[:3]
+        from_fill_parent_, fill_ = fill_fixture[3:]
+
+        fill = background.fill
+
+        assert cSld.xml == expected_xml
+        from_fill_parent_.assert_called_once_with(
+            cSld.xpath('p:bg/p:bgPr')[0]
+        )
+        assert fill is fill_
+
+    # fixtures -------------------------------------------------------
+
+    @pytest.fixture(params=[
+        ('p:cSld{a:b=c}',
+         'p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)'),
+        ('p:cSld{a:b=c}/p:bg/p:bgRef',
+         'p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)'),
+        ('p:cSld/p:bg/p:bgPr/a:solidFill',
+         'p:cSld/p:bg/p:bgPr/a:solidFill'),
+    ])
+    def fill_fixture(self, request, from_fill_parent_, fill_):
+        cSld_xml, expected_cxml = request.param
+        cSld = element(cSld_xml)
+        background = _Background(cSld)
+
+        from_fill_parent_.return_value = fill_
+
+        expected_xml = xml(expected_cxml)
+        return background, cSld, expected_xml, from_fill_parent_, fill_
+
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def fill_(self, request):
+        return instance_mock(request, FillFormat)
+
+    @pytest.fixture
+    def from_fill_parent_(self, request):
+        return method_mock(request, FillFormat, 'from_fill_parent')
